******************************
***Florida Sibling Analysis***
***Jenni Heissel**************
***July 25, 2014**************
***Analyzing FL Data**********
******************************
******************************

use "D:\Sibling Spillover\data\d_cleaned data.dta", clear
	set more off
***all years
*preserve
*qui: hist years_rel_birth, start (-15) width(1) graphregion(color(white)) bgcolor(white) freq ///
*	title(Years Relative to Sister's First Birth)
*	graph export "C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\hist_years_since_birth.png", replace
*restore

***Limit population: Only sibings from families with at least one teen mom (age 15-17)
**Siblings may include people from families with 1 sib <16, 1 at least 15
drop if  age_at_birth   !=15		&age_at_birth   !=16		&age_at_birth!=17&mom==1
drop if  age_at_birth_mom_max!=15&age_at_birth_mom_max!=16&age_at_birth_mom_max!=17&sib==1|age_at_birth_mom_min!=15&age_at_birth_mom_min!=16&age_at_birth_mom_min!=17&sib==1
*keep if age_dif<abs(10)|age_dif==.

gen age2=age*age
gen age3=age*age2
gen age_cont2=age_cont*age_cont

***limit to having at least an observation at t=0 and one before that 
	*egen temp=min(years_rel_birth) if sib+mom!=0, by(id)
	*	tab temp
	*	drop if temp>=0&temp!=.
	*gen temp2=0 if years_rel_birth==0
	*	egen temp3=mean(temp2), by(id)
	*	drop if temp3==.&sib+mom!=0
	*drop temp
	*drop temp temp2 temp3
**and SIBS must have an obs at T=0 and at least 1 at T=-2, -3, -4, or -5
*drop if panelreq==0&sib==1
**Must be YOUNGER siblings
drop if age_dif_older==1&sib==1

***JAH 6/14/18: making the matching have an older sister
egen temp= min( birthdate) if female==1, by(famid)
egen temp2=mean(temp), by(famid)
gen has_older_sister=(birthdate>temp2)
tab sib has_older_sister if age_dif_older==0
	drop temp temp2

*R-squared review
	sort panel testyear
	reg mathnp L5.readnp if grade==8&L5.grade==3
	reg readnp L5.mathnp if grade==8&L5.grade==3
	
***setting random
set seed 123456
gen random=runiform()
sort random

***Creating matched synthetic control group
	eststo clear
*	local if "if mom+sib==0&seq==1|sib==1&seq==1"
*all main analysis to be the same population:
	local if "if mom+sib==0&has_older_sister==1	&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003 |sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003"
eststo col1: logit sib female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first `if'
		estat ic
		*predict phat1 `if'
		*gen     phat2=phat1+grid_first*10 `if'
*limited to minimize AIC
eststo col2: eststo col1: logit sib female i.age oldest frl black first_school_frl first_school_pcti_first `if'
		predict phat3 `if'
		gen     phat4=phat3+grid_first*10 `if'

***longitudinal matching
*only scores
eststo: logit sib pctiL1 pctiL2 pctiL3 missing_pctiL1 missing_pctiL2 missing_pctiL3 oldest  `if'    
		predict phat5 `if'
*other controls 
***Creating matched synthetic control group
*other controls 
eststo col4: eststo col4: logit sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first `if'
estat ic
*limited:
eststo col5: logit sib female i.age oldest frl black pctiL1 pctiL2 pctiL3 missing_pctiL1 first_school_frl first_school_pcti_first `if'
		predict phat6 `if'
		gen     phat7=phat6+grid_first*10 `if'
	esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA2_logit.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("Model 1" "Model 2") 
***only year t=-2 (recency estimate)
		logit sib female i.age famcount oldest frl black pctiL1 missing_pctiL1 first_school_frl first_school_black first_school_pcti_first `if'
eststo col3: logit sib female i.age famcount oldest frl black pctiL1 missing_pctiL1 first_school_frl first_school_pcti_first `if'
		predict phat19 `if'
		gen     phat20=phat19+grid_first*10 `if'

***Family & individual trajectory 
local if "if mom+sib==0&has_older_sister==1	&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1 & missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1&testyear<2003 |sib==1 &years_rel_birth==-1 & missing_pctiL1+missing_pctiL2+missing_pctiL3<=1 & missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1 & testyear<2003"
		logit sib female i.age famcount oldest frl black pcti_famL1 pcti_famL2 pcti_famL3  missing_pcti_famL1 missing_pcti_famL2 missing_pcti_famL3 pctiL1 pctiL2 pctiL3  missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first `if'
		eststo col6: logit sib female i.age oldest frl black pcti_famL3 missing_pcti_famL2 pctiL2 pctiL3  missing_pctiL1 first_school_frl first_school_pcti_first `if'
		predict phat23 `if'
		gen     phat24=phat23+grid_first*10 `if'	

***Table:
esttab col1 col2 col3 col4 col5 col6 using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA3_LogitTable_OlderSisReq.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("1st OBS" "1st OBs AIC" "T=-2 AIC" "IND" "IND AIC" "INd+FAM")

				
	eststo clear

***Other options for matching - changing years used
*baseline: -4 to -2
eststo: logit sib female i.age oldest frl black pctiL1 pctiL2 pctiL3 missing_pctiL1 first_school_frl first_school_pcti_first `if'
*-4 to -3
		logit sib female i.age  famcount oldest frl black   pctiL2 pctiL3 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first   if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3<=1&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3<=1&testyear<2003
eststo: logit sib female i.age oldest frl black   pctiL2 pctiL3 first_school_frl first_school_pcti_first   if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3<=1&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3<=1&testyear<2003
		predict phat8     						if mom+sib==0&has_older_sister==1&has_older_sister==1&missing_pctiL2+missing_pctiL3<=1&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3<=1&testyear<2003
		replace phat8=phat8+grid_first*10 		if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3<=1&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3<=1&testyear<2003
*-3 to -1
		logit sib female i.age  famcount oldest frl black   pctiL0 pctiL1 pctiL2 missing_pctiL0 missing_pctiL1 missing_pctiL2 first_school_frl first_school_black first_school_pcti_first  if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL0<=1&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL0<=1&testyear<2003
eststo: logit sib female i.age  famcount oldest frl black   pctiL0 first_school_frl first_school_black  if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL0<=1&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL0<=1&testyear<2003
		predict phat9    						if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL0<=1&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL0<=1&testyear<2003
		replace phat9=phat9+grid_first*10     	if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL0<=1&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL0<=1&testyear<2003
*-5 to -2
		logit sib female i.age  famcount oldest frl black   pctiL1 pctiL2 pctiL3 pctiL4 missing_pctiL1 missing_pctiL2 missing_pctiL3 missing_pctiL4 first_school_frl first_school_black first_school_pcti_first   if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3+missing_pctiL4+missing_pctiL1<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3+missing_pctiL4+missing_pctiL1<=2&testyear<2003
eststo: logit sib female i.age oldest frl black   pctiL1 pctiL2 pctiL3 missing_pctiL1 first_school_frl first_school_pcti_first   if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3+missing_pctiL4+missing_pctiL1<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3+missing_pctiL4+missing_pctiL1<=2&testyear<2003
		predict phat10    						if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3+missing_pctiL4+missing_pctiL0<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3+missing_pctiL4+missing_pctiL0<=2&testyear<2003
		replace phat10=phat10+grid_first*10    if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3+missing_pctiL4+missing_pctiL0<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3+missing_pctiL4+missing_pctiL0<=2&testyear<2003
*-4 to -1
		logit sib female i.age  famcount oldest frl black  pctiL0 pctiL1 pctiL2 pctiL3 missing_pctiL0 missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first   if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3+missing_pctiL1+missing_pctiL0<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3+missing_pctiL1+missing_pctiL0<=2&testyear<2003
eststo: logit sib female i.age  famcount oldest frl black  pctiL0 pctiL2 pctiL3 first_school_frl first_school_black   if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3+missing_pctiL1+missing_pctiL0<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3+missing_pctiL1+missing_pctiL0<=2&testyear<2003
		predict phat11     						if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3+missing_pctiL1+missing_pctiL0<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3+missing_pctiL1+missing_pctiL0<=2&testyear<2003
		replace phat11=phat11+grid_first*10     if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3+missing_pctiL1+missing_pctiL0<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3+missing_pctiL1+missing_pctiL0<=2&testyear<2003

*baseline: -4 to -2 - adding FAMILY trajectory
*-4 to -3
local if "if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3<=1&missing_pctiL2+missing_pctiL3<=1&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3<=1&missing_pctiL2+missing_pctiL3<=1&testyear<2003"
		logit sib female i.age  famcount oldest frl black   pcti_famL2 pcti_famL3  missing_pcti_famL2 missing_pcti_famL3 pctiL2 pctiL3 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first   `if'
eststo: logit sib i.age oldest frl black pcti_famL3  missing_pcti_famL2 pctiL2 pctiL3 missing_pctiL2 first_school_frl first_school_pcti_first   `if'
		predict phat25    `if'
*-3 to -1
local if "if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL0<=1&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL0<=1&testyear<2003"
		logit sib female i.age  famcount oldest frl black   pcti_famL0 pcti_famL1 pcti_famL2  missing_pcti_famL0 missing_pcti_famL1 missing_pcti_famL2 pctiL0 pctiL1 pctiL2 missing_pctiL0 missing_pctiL1 missing_pctiL2 first_school_frl first_school_black first_school_pcti_first  `if'
eststo: logit sib i.age  famcount oldest frl black   pcti_famL0 pcti_famL1 pcti_famL2  missing_pcti_famL0 missing_pcti_famL1 missing_pcti_famL2 missing_pctiL0 missing_pctiL1 missing_pctiL2 first_school_frl first_school_black  `if'
		predict phat26     `if'
*-5 to -2
local if "if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3+missing_pctiL4+missing_pctiL1<=2&missing_pcti_famL2+missing_pcti_famL3+missing_pcti_famL4+missing_pcti_famL1<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3+missing_pctiL4+missing_pctiL1<=2&missing_pcti_famL2+missing_pcti_famL3+missing_pcti_famL4+missing_pcti_famL1<=2&testyear<2003"
		logit sib female i.age  famcount oldest frl black   pcti_famL1 pcti_famL2 pcti_famL3 pcti_famL4 missing_pcti_famL1 missing_pcti_famL2 missing_pcti_famL3 missing_pcti_famL4 pctiL1 pctiL2 pctiL3 pctiL4 missing_pctiL1 missing_pctiL2 missing_pctiL3 missing_pctiL4 first_school_frl first_school_black first_school_pcti_first   `if'  
eststo: logit sib i.age oldest frl black pcti_famL4 missing_pcti_famL2 missing_pcti_famL4 pctiL1 pctiL2 pctiL3 missing_pctiL2 first_school_frl first_school_pcti_first   `if'
		predict phat27      `if'
*-4 to -1
local if "if mom+sib==0&has_older_sister==1&missing_pctiL2+missing_pctiL3+missing_pctiL1+missing_pctiL0<=2&missing_pcti_famL2+missing_pcti_famL3+missing_pcti_famL1+missing_pcti_famL0<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL2+missing_pctiL3+missing_pctiL1+missing_pctiL0<=2&missing_pcti_famL2+missing_pcti_famL3+missing_pcti_famL1+missing_pcti_famL0<=2&testyear<2003"
		logit sib female i.age  famcount oldest frl black  pcti_famL0 pcti_famL1 pcti_famL2 pcti_famL3 missing_pcti_famL0 missing_pcti_famL1 missing_pcti_famL2 missing_pcti_famL3 pctiL0 pctiL1 pctiL2 pctiL3 missing_pctiL0 missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first   `if'
eststo: logit sib  i.age  famcount oldest frl black  pcti_famL0 pcti_famL1 pcti_famL3 missing_pcti_famL0 missing_pcti_famL2 pctiL0 pctiL2 pctiL3 missing_pctiL0 missing_pctiL2 first_school_frl first_school_pcti_first   `if'
		predict phat28     `if'
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TAOther_logit_alttraj.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("Trajectory: Years -4 to -2" "Trajectory: Years -4 to -3" "Trajectory: Years -3 to -1" "Trajectory: Years -5 to -2" "Trajectory: Years -4 to -1"   ///
					   "Adding family trajectory: Years -4 to -2" "Trajectory: Years -4 to -3" "Trajectory: Years -3 to -1" "Trajectory: Years -5 to -2" "Trajectory: Years -4 to -1" )  
	eststo clear
***other options for matching - different data restrictions
eststo clear
		logit sib female i.age  famcount oldest frl black   pctiL1 pctiL2 pctiL3 missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first   if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=2&testyear<2003
eststo: logit sib i.age oldest frl black   pctiL1 pctiL2 pctiL3 missing_pctiL1 first_school_frl first_school_pcti_first   if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=2&testyear<2003
		predict phat12 							if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=2&testyear<2003
		replace phat12=phat12+grid_first*10 	if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=2&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=2&testyear<2003
		logit sib female i.age  famcount oldest frl black   pctiL1 pctiL2 pctiL3 missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first    if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=0&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=0&testyear<2003
eststo: logit sib female i.age oldest frl black   pctiL1 pctiL2 pctiL3    if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=0&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=0&testyear<2003
		predict phat13 							if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=0&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=0&testyear<2003
		replace phat13=phat13+grid_first*10 	if mom+sib==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=0&testyear<2003|sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=0&testyear<2003
	esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TAOther_logit_altlimits.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("Must have at least 1" "Must have all 3") 
eststo clear

***other options for identifying births
eststo clear
local if "if mom2+sib2==0&has_older_sister==1&oldest==0&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1&testyear<2003 |sib2==1&oldest==0&years_rel_birth2==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1&testyear<2003"
		logit sib2 female i.age  famcount oldest frl black  pcti_famL1 pcti_famL2 pcti_famL3  missing_pcti_famL1 missing_pcti_famL2 missing_pcti_famL3 pctiL1 pctiL2 pctiL3 missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first   `if'
eststo: logit sib2 female i.age oldest frl black pcti_famL2  missing_pcti_famL1 pctiL1 pctiL3 first_school_frl first_school_pcti_first   `if'
		predict phat14 							`if'
		*replace phat14=phat14+grid_first*10 	`if'
local if "if mom3+sib3==0&has_older_sister==1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1&testyear<2003 |sib2==1&years_rel_birth2==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1&testyear<2003"
		logit sib3 female i.age  famcount oldest frl black  pcti_famL1 pcti_famL2 pcti_famL3  missing_pcti_famL1 missing_pcti_famL2 missing_pcti_famL3 pctiL1 pctiL2 pctiL3 missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first   `if'
eststo: logit sib3 female i.age oldest frl black  pcti_famL1  missing_pcti_famL1 pctiL1 first_school_black   `if'
		predict phat15 							`if'
		*replace phat15=phat15+grid_first*10 	`if'
local if "if oldest==0&has_older_sister==1&mom4+sib4==0&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1&testyear<2003 |sib2==1&oldest==0&years_rel_birth2==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1&testyear<2003"
		logit sib4 female i.age  famcount oldest frl black  pcti_famL1 pcti_famL2 pcti_famL3  missing_pcti_famL1 missing_pcti_famL2 missing_pcti_famL3 pctiL1 pctiL2 pctiL3 missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first   `if'
eststo: logit sib4 female i.age oldest frl black pcti_famL2  missing_pcti_famL1  pctiL1 pctiL3 first_school_frl first_school_pcti_first   `if'
		predict phat16 							`if'
		*replace phat16=phat16+grid_first*10		`if'
	esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TAOther_logit_altbirthdefs.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("Parent program then birth" "Birth only" "Parent program only") 
eststo clear

***other odds & ends
**without first-observed schools scores
local if "if mom+sib==0&has_older_sister==1	&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003 |sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003"
		logit sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3  missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black `if'
eststo: logit sib female i.age oldest frl black pctiL1 pctiL2 pctiL3  missing_pctiL1 first_school_frl first_school_black `if'
		predict phat17 `if'
		gen     phat18=phat17+grid_first*10 `if'

**Add family data availability requirements
local if "if mom+sib==0&has_older_sister==1	&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1 & missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1&testyear<2003 |sib==1 &years_rel_birth==-1 & missing_pctiL1+missing_pctiL2+missing_pctiL3<=1 & missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3<=1 & testyear<2003"

***Family trajectory only
		logit sib female i.age famcount oldest frl black pcti_famL1 pcti_famL2 pcti_famL3  missing_pcti_famL1 missing_pcti_famL2 missing_pcti_famL3 first_school_frl first_school_black first_school_pcti_first `if'
eststo: logit sib i.age oldest frl black pcti_famL2 pcti_famL3 missing_pcti_famL2 first_school_frl first_school_pcti_first `if'
		predict phat21 `if'
		gen     phat22=phat21+grid_first*10 `if'
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TAOther_logit_oddsends.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("No first school scores" "Based on t=-2" "Based on family trajectory t=-4 to -2" "Based on ind & family trajectory t=-4 to -2") 		

***used for PandP:
eststo: logit sib female age_cont famcount oldest frl black  pctiL1 pctiL2 pctiL3 missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first if mom+sib==0&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003 |sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003
eststo: logit sib female age_cont famcount oldest frl black  pctiL1 pctiL2 pctiL3 missing_pctiL2 missing_pctiL3 first_school_frl first_school_pcti_first if mom+sib==0&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003 |sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003				
		predict phat29 if mom+sib==0&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003 |sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003
		gen     phat30=phat29+grid_first*10 if mom+sib==0&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003 |sib==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003	
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TAOther_logit_oddsends.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("Full" "Limited") 		
				
**making group id's for sibs
	preserve
	**make a list of ids for siblings with data in year=0
	keep if sib==1&years_rel_birth==-1
	bys id: gen pop = 1 if _n==1
	replace pop = sum(pop) 
	keep id pop
	collapse pop, by(id)
	tempfile pop
	save `pop', replace
	restore
	merge m:1 id using `pop'
	drop _merge
	egen maxpop = max(pop)
	local end = maxpop[1]
	drop maxpop
	
**making a list of IDs
preserve
	clear
	gen id=""
	gen testyear=.
	gen series=.
	tempfile list
	save `list', replace
restore

	tempfile main
	save `main', replace

	tab pop if pop==`end'

	forv w = 3/30 {
	*foreach w in 3 4 5 6 7 19 20 23 24 {
	*forv w = 6/7 {
		*forv i = 1/20	{
		forv i = 1/`end'	{
			use `main', clear
			keep if mom+sib==0&phat`w'!=.|sib==1&years_rel_birth==-1&pop==`i'&phat`w'!=.
			egen max_sib=max(sib)
			if max_sib==0 {
				disp "w - i is "`w' `i'
				}
			else {
			forv j = 1/5 {
				qui: psmatch2 sib, pscore(phat`w') neighbor(1) out(testyear) caliper(1)
				preserve
					keep if _weight==1 & sib==0
					gen series=`j'*1000+`i'
					keep id testyear series
					append using `list'
					save `list', replace
				restore
				egen temp=max(_weight), by(id)
				drop if sib==0&temp==1
				drop temp
					}
				disp "w - i is "`w' " " `i'
				}
			}
			use `list', clear
			collapse (count) series, by(id testyear)
			replace series=series/5
			rename series weight`w'
			***added 7/7/17, give new id system (have to avoid duplicates by year; matches may be matched in multile years), 12/15: difference for PandP
			if `w'<29 {
				gen n=_n
				egen id2=concat(id n)
				drop n
				}
			else {
				display "OLD"
					}
			save `list', replace
				*sidetrip to make weighted list of times relative to the matchesd year (i.e., years_rel_birth for all)
				if `w'==2|`w'== 3|`w'== 4|`w'== 19|`w'== 20|`w'== 6|`w'== 7|`w'== 23|`w'== 24|`w'== 25|`w'== 26|`w'== 27|`w'==28 {
				preserve
					*make 8 obs per sample
					expand 8
					*make one for each year -5 to +2 relative to year 0 (year of match)
					*added 7/7/17, "by id ***testyear***"  12/15: dif for PandP
					if `w'<29 {
					sort id2 testyear
					by id2 testyear: generate long obs = _n
					disp "NEW"
						}
					else {
					sort id testyear
					by id: generate long obs = _n
					disp "OLD"
						}
					
					rename (testyear weight`w') (testyear_match weight`w'_rel)
					gen years_rel_birth=obs-6
					*plus one b/c match occurs year before birth!
					gen  testyear=testyear_match+years_rel_birth+1
					tempfile temp
					save `temp'
					*add siblings, match to test scores by year
					use `main', clear
						***back to old way for PandP:
						keep id testyear years_rel_birth sib phat`w'
						if `w'<29 {
							egen keep=max(phat`w'), by(id)
							keep if sib==1&keep!=.
							drop phat`w' keep
							}
						else {
							keep if sib==1
							}
						gen weight`w'_rel=1
						append using `temp'
						merge m:1 id testyear using `main'
						***added 7/9/17: replacing newid
						if `w'<29 {
						replace id2=id if id2==""
						disp "NEW"
							}
						else {
						disp "OLD"
							}
						replace sib=0 if sib==.
						drop yrm5 yrm4 yrm3 yrm2 yrm1 yrm0 yr0 yr1 yr2 yr3 yr4 yr5
						tab years_rel_birth if abs(years_rel_birth)<6, g(yr)
							rename yr1 yrm5
							rename yr2 yrm4
							rename yr3 yrm3
							rename yr4 yrm2
							rename yr5 yrm1
							rename yr6 yr0
							rename yr7 yr1
							rename yr8 yr2
							rename yr9 yr3
							rename yr10 yr4
							rename yr11 yr5
							gen yrm0=yr0

							label variable  yrm5  "5 years before birth"
							label variable  yrm4  "4 years before birth"
							label variable  yrm3  "3 years before birth"
							label variable  yrm2  "2 years before birth"
							label variable  yrm1  "1 years before birth"
							label variable  yrm0  "Year of birth"
							label variable  yr0  "Year of birth"
							label variable  yr1  "1 years after birth"
							label variable  yr2  "2 years after birth"
							label variable  yr3  "3 years after birth"
							label variable  yr4  "4 years after birth"
							label variable  yr5  "5 years after birth"
							
							***added 7/9/17 to redo panel with new id, 12/15: not for PandP: 
							if `w'<29 {
								drop if years_rel_birth==.
								***recreating panel
								drop panel
								sort id2
								egen panel = group( id2 )
								sort panel testyear
								quietly by panel testyear:  gen dup = cond(_N==1,0,_n)
								tab dup
								disp "NEW"
								}
							else {
								sort panel testyear
								quietly by panel testyear:  gen dup = cond(_N==1,0,_n)
								tab dup
								drop if dup>1
								drop dup
								display "OLD"
								}
							tsset panel testyear
					save "D:\Sibling Spillover\data\OlderSibReq\b_years_rel_birth_`w'", replace	
					restore
							}

					else {
						display "skip FE for weight `w'"
						}

			merge 1:m id testyear using `main'
				display "1"
			drop _merge
				display "2"
			if `w'<29 {
				***Making sure sibs are eligible Added 7/9/17:
				replace weight`w'=1 if sib==1&years_rel_birth==-1&phat`w'!=.
				}
			else {
				replace weight`w'=1 if sib==1&years_rel_birth==-1
				}
			display "3"
			save `main', replace
			display "4"
			use `list', clear
			display "5"
				drop _all
				display "6"
				gen id=""
				display "7"
				gen testyear=.
				display "8"
				gen series=.
				display "9"
			save `list', replace
			display "10"
		}
		
use `main', clear
sum weight*		

*forv w=3/30 {
foreach w in 3 4 5 6 7 19 20 23 24 {
*forv w=3/7 {
	egen weight`w'_fe=sum(weight`w') if sib+mom==0, by(id)
	egen phat`w'_max=max(phat`w'), by(id)
	replace weight`w'_fe=1 if sib==1&phat`w'_max!=.
	drop phat`w'_max
	}
	
sum  missing_pctL* if years_rel_birth==0&sib==1	
		
save "D:\Sibling Spillover\data\b_final_oldersisreq", replace
