******************************
***Florida Sibling Analysis***
***Jenni Heissel**************
***July 25, 2014**************
***Analyzing FL Data**********
******************************
******************************

use "D:\Sibling Spillover\data\b_final.dta", clear
	set more off
***all years
*preserve
*qui: hist years_rel_birth, start (-15) width(1) graphregion(color(white)) bgcolor(white) freq ///
*	title(Years Relative to Sister's First Birth)
*	graph export "C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\hist_years_since_birth.png", replace
*restore

***Limit population: Only sibings from families with at least one teen mom (age 15-17)
**Siblings may include people from families with 1 sib <16, 1 at least 15
drop if  age_at_birth   !=15		&age_at_birth   !=16		&age_at_birth!=17&mom==1
drop if  age_at_birth_mom_max!=15&age_at_birth_mom_max!=16&age_at_birth_mom_max!=17&sib==1|age_at_birth_mom_min!=15&age_at_birth_mom_min!=16&age_at_birth_mom_min!=17&sib==1
keep if age_dif<abs(10)|age_dif==.

***limit to having at least an observation at t=0 and one before that - 
	egen temp=min(years_rel_birth) if sib+mom!=0, by(id)
		tab temp
		drop if temp>=0&temp!=.
	*gen temp2=0 if years_rel_birth==0
	*	egen temp3=mean(temp2), by(id)
	*	drop if temp3==.&sib+mom!=0
	drop temp
	*drop temp temp2 temp3
**and SIBS must have an obs at T=0 and at least 1 at T=-2, -3, -4, or -5
*drop if panelreq==0&sib==1
**Must be YOUNGER siblings
drop if age_dif_older==1&sib==1

***setting random
set seed 123456
sort random

***Creating matched synthetic control group
	eststo clear
*	local if "if mom+sib==0&seq==1|sib==1&seq==1"
*all main analysis to be the same population:
	local if "if mom+sib==0&missing_pctiL1+missing_pctiL2+missing_pctiL3+missing_pctiL4<=2&testyear<2003|mom==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3+missing_pctiL4<=2&testyear<2003"
	eststo: logit mom female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first `if'
		estat ic
		predict phat101 `if'
		gen     phat102=phat101+grid_first*10 `if'
*limited to minimize AIC
eststo: eststo: logit mom female i.age oldest frl black pcti_first first_school_pcti_first `if'
		predict phat103 `if'
		gen     phat104=phat103+grid_first*10 `if'

***longitudinal matching
*only scores
	eststo: logit mom pctiL1 pctiL2 pctiL3 pctiL4 missing_pctiL1 missing_pctiL2 missing_pctiL3 missing_pctiL4 female  `if'    
		predict phat105 `if'
*other controls 
eststo: logit mom female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3  pctiL4 missing_pctiL1 missing_pctiL2 missing_pctiL3 missing_pctiL4 first_school_frl first_school_black first_school_pcti_first `if'
eststo: logit mom female i.age oldest frl black pctiL1 pctiL4 missing_pctiL1 missing_pctiL3 first_school_pcti_first `if'
		predict phat106 `if'
		gen     phat107=phat106+grid_first*10 `if'
	esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\TA4_logit_moms.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("Model 1" "Model 2") 
	eststo clear
***Other options for matching
*baseline: -5 to -2
eststo: logit mom female i.age oldest frl black pctiL1 pctiL4 missing_pctiL1 missing_pctiL3 first_school_pcti_first `if'
**-5 to -1
	local if "if mom+sib==0&missing_pctiL0+missing_pctiL1+missing_pctiL2+missing_pctiL3+missing_pctiL4<=2&testyear<2003|mom==1&years_rel_birth==-1&missing_pctiL0+missing_pctiL1+missing_pctiL2+missing_pctiL3+missing_pctiL4<=2&testyear<2003"
		logit mom female i.age famcount oldest  frl black  pctiL0 pctiL1 pctiL2 pctiL3 pctiL4 missing_pctiL0 missing_pctiL1 missing_pctiL2 missing_pctiL3 missing_pctiL4 first_school_frl first_school_black first_school_pcti_first  `if'
eststo: logit mom female i.age oldest  frl black  pctiL0 missing_pctiL0 missing_pctiL1 missing_pctiL4 first_school_pcti_first  `if'
		predict phat108     `if'
		*replace phat108=phat108+grid_first*10 `if'
*-3 to -1
	local if "if mom+sib==0&missing_pctiL0+missing_pctiL1+missing_pctiL2<=1&testyear<2003|mom==1&years_rel_birth==-1&missing_pctiL0+missing_pctiL1+missing_pctiL2<=1&testyear<2003"
		logit mom female i.age famcount oldest  frl black pctiL0 pctiL1 pctiL2 missing_pctiL0 missing_pctiL1 missing_pctiL2 first_school_frl first_school_black first_school_pcti_first `if'
eststo: logit mom female i.age oldest  frl black pctiL0 missing_pctiL0 missing_pctiL1 first_school_pcti_first `if'
		predict phat109     `if'
		*replace phat109=phat109+grid_first*10 `if'
*-4 to -2
	local if "if mom+sib==0&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003|mom==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3<=1&testyear<2003"
		logit mom female i.age famcount oldest  frl black  pctiL1 pctiL2 pctiL3 missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first   `if'
eststo: logit mom female i.age oldest  frl black  pctiL1 pctiL2 missing_pctiL1 missing_pctiL3 first_school_pcti_first   `if'
		predict phat110     `if'
		*replace phat110=phat110+grid_first*10 `if'
*-4 to -1
	local if "if mom+sib==0&missing_pctiL0+missing_pctiL1+missing_pctiL2+missing_pctiL3<=2&testyear<2003|mom==1&years_rel_birth==-1&missing_pctiL0+missing_pctiL1+missing_pctiL2+missing_pctiL3<=2&testyear<2003"
		logit mom female i.age famcount oldest  frl black  pctiL0 pctiL1 pctiL2 pctiL3 missing_pctiL0 missing_pctiL1 missing_pctiL2 missing_pctiL3 first_school_frl first_school_black first_school_pcti_first  `if'
eststo: logit mom female i.age oldest  frl black  pctiL0 missing_pctiL0 missing_pctiL1 missing_pctiL3 first_school_pcti_first  `if'
		predict phat111    `if'
		*replace phat111=phat111+grid_first*10 `if'
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\TAOther_logit_alttraj_moms.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("Trajectory: Years -5 to -2" "Trajectory: Years -5 to -1" "Trajectory: Years -3 to -1" "Trajectory: Years -5 to -2" "Trajectory: Years -4 to -2" ) 
	eststo clear

***Alternative models
	local if "if mom+sib==0&missing_pctiL1+missing_pctiL2+missing_pctiL3+missing_pctiL4<=2&testyear<2003|mom==1&years_rel_birth==-1&missing_pctiL1+missing_pctiL2+missing_pctiL3+missing_pctiL4<=2&testyear<2003"
**Baseline
	logit mom female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3  pctiL4 missing_pctiL1 missing_pctiL2 missing_pctiL3 missing_pctiL4 first_school_frl first_school_black first_school_pcti_first `if'
**No first observed school scores 
		logit mom female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3  pctiL4 missing_pctiL1 missing_pctiL2 missing_pctiL3 missing_pctiL4 first_school_frl first_school_black `if'
eststo: logit mom female i.age oldest frl black pctiL1 pctiL4 missing_pctiL1 missing_pctiL3 first_school_frl `if'
	predict phat117 `if'
	gen phat118=phat117+grid_first*10 `if'
**Only t=-2 scores
		logit mom female i.age famcount oldest frl black pctiL1 missing_pctiL1 first_school_frl first_school_black first_school_pcti_first `if'
eststo: logit mom female i.age oldest frl black pctiL1 missing_pctiL1 first_school_pcti_first `if'	
	predict phat119 `if'
	gen phat120=phat119+grid_first*10 `if'
**Family trajectory
local if "if mom+sib==0	&missing_pctiL1+missing_pctiL2+missing_pctiL3+missing_pctiL4<=2 & missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3+missing_pcti_famL4<=2&testyear<2003 |mom==1 &years_rel_birth==-1 & missing_pctiL1+missing_pctiL2+missing_pctiL3+missing_pctiL4<=2 & missing_pcti_famL1+missing_pcti_famL2+missing_pcti_famL3+missing_pcti_famL4<=2 & testyear<2003"
		logit mom female i.age famcount oldest frl black pcti_famL1 pcti_famL2 pcti_famL3 pcti_famL4 missing_pcti_famL1 missing_pcti_famL2 missing_pcti_famL3 missing_pcti_famL4 first_school_frl first_school_black first_school_pcti_first `if'
eststo: logit mom female i.age oldest frl black pcti_famL1 missing_pcti_famL1 first_school_frl first_school_pcti_first `if'
	predict phat121 `if'
	gen phat122=phat121+grid_first*10 `if'
	**Individual & Family trajectory
		logit mom female i.age famcount oldest frl black pcti_famL1 pcti_famL2 pcti_famL3 pcti_famL4 missing_pcti_famL1 missing_pcti_famL2 missing_pcti_famL3 missing_pcti_famL4 pctiL1 pctiL2 pctiL3  pctiL4 missing_pctiL1 missing_pctiL2 missing_pctiL3 missing_pctiL4 first_school_frl first_school_black first_school_pcti_first `if'
eststo: logit mom female i.age frl black pcti_famL1 missing_pcti_famL3 pctiL2  pctiL4 missing_pctiL1 missing_pctiL3 first_school_frl first_school_pcti_first `if'
	predict phat123 `if'
	gen phat124=phat123+grid_first*10 `if'
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\TA5B_logit_oddsends_moms.rtf, ///
				star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
				nonum b(3) se(3) replace label onecell ///
				mtitle("No first school scores" "Based on t=-2" "Based on family trajectory t=-4 to -2" "Based on ind & family trajectory t=-4 to -2") 		
	
**making group id's for mom
	preserve
	**make a list of ids for moms with data in year=0
	keep if mom==1&years_rel_birth==-1
	drop pop 
	bys id: gen pop = 1 if _n==1
	replace pop = sum(pop) 
	keep id pop
	collapse pop, by(id)
	tempfile pop
	save `pop', replace
	restore
	drop pop
	merge m:1 id using `pop'
	drop _merge
	egen maxpop = max(pop)
	local end = maxpop[1]
	drop maxpop
	
**making a list of IDs
preserve
	clear
	gen id=""
	gen testyear=.
	gen series=.
	tempfile list
	save `list', replace
restore

	tempfile main
	save `main', replace

	tab pop if pop==`end'

*	foreach w in 103 104 105 106 107 108 109 110 111 117 118 119 120 121 122 123 124 {
	foreach w in 103 104 106 107 119 120 121 122 123 124 {

		*forv i = 1/3	{
		forv i = 1/`end'	{
			use `main', clear
			keep if mom+sib==0&phat`w'!=.|mom==1&years_rel_birth==-1&pop==`i'&phat`w'!=.
			egen max_mom=max(mom)
			if max_mom==0 {
				disp "w - i is "`w' `i'
				}
			else {
			forv j = 1/5 {
				psmatch2 mom, pscore(phat`w') neighbor(1) out(testyear) caliper(1)
				preserve
					keep if _weight==1 & mom==0
					gen series=`j'*1000+`i'
					keep id testyear series
					append using `list'
					save `list', replace
				restore
				egen temp=max(_weight), by(id)
				drop if mom==0&temp==1
				drop temp
					}
				disp "w - i is "`w' `i'
				}
			}
			display "use list"
			use `list', clear
			display "collapse"
			collapse (count) series, by(id testyear)
			display "collapsed"
			replace series=series/5
			rename series weight`w'
			***give new id system (have to avoid duplicates by year; matches may be matched in multile years)
			gen n=_n
			egen id2=concat(id n)
			drop n
			save `list', replace
				*sidetrip to make weighted list of times relative to the matchesd year (i.e., years_rel_birth for all)
				if `w'== 103|`w'== 104|`w'== 119|`w'== 120|`w'== 106|`w'== 107|`w'== 123|`w'== 124 {
				display "expansion"
				preserve
					*make 8 obs per sample
					expand 8
					*make one for each year -5 to +2 relative to year 0 (year of match)
					sort id2 testyear
					*added 7/12/17, "by id2 ***testyear***"
					by id2 testyear: generate long obs = _n
					rename (testyear weight`w') (testyear_match weight`w'_rel)
					gen years_rel_birth=obs-6
					*plus one b/c match occurs 1 years before birth!
					gen  testyear=testyear_match+years_rel_birth+1
					tempfile temp
					save `temp'
					*add moms, match to test scores by year
					use `main', clear
						keep id testyear years_rel_birth mom phat`w'
						egen keep=max(phat`w'), by(id)
						keep if mom==1&keep!=.
						drop phat`w' keep
						gen weight`w'_rel=1
						append using `temp'
						merge m:1 id testyear using `main'
						***7/9/17: replacing newid
						replace id2=id if id2==""
						replace mom=0 if mom==.
						drop yrm5 yrm4 yrm3 yrm2 yrm1 yrm0 yr0 yr1 yr2 yr3 yr4 yr5
						tab years_rel_birth if abs(years_rel_birth)<6, g(yr)
							rename yr1 yrm5
							rename yr2 yrm4
							rename yr3 yrm3
							rename yr4 yrm2
							rename yr5 yrm1
							rename yr6 yr0
							rename yr7 yr1
							rename yr8 yr2
							rename yr9 yr3
							rename yr10 yr4
							rename yr11 yr5
							gen yrm0=yr0

							label variable  yrm5  "5 years before birth"
							label variable  yrm4  "4 years before birth"
							label variable  yrm3  "3 years before birth"
							label variable  yrm2  "2 years before birth"
							label variable  yrm1  "1 years before birth"
							label variable  yrm0  "Year of birth"
							label variable  yr0  "Year of birth"
							label variable  yr1  "1 years after birth"
							label variable  yr2  "2 years after birth"
							label variable  yr3  "3 years after birth"
							label variable  yr4  "4 years after birth"
							label variable  yr5  "5 years after birth"

							***added 7/9/17 to redo panel with new id: 
							drop if years_rel_birth==.
							***recreating panel
							drop panel
							sort id2
							egen panel = group( id2 )
							sort panel testyear
							quietly by panel testyear:  gen dup = cond(_N==1,0,_n)
							tab dup

							tsset panel testyear
					
					save "D:\Sibling Spillover\data\b_years_rel_birth_`w'", replace	
				restore
						}
					else {
						display "skip FE for weight `w'"
						}				
				
			merge 1:m id testyear using `main'
				display "1"
			drop _merge
				display "2"
			***Making sure sibs are eligible Added 1/2/18:
			replace weight`w'=1 if mom==1&years_rel_birth==-1&phat`w'!=.
			display "3"
			save `main', replace
			display "4"
			use `list', clear
			display "5"
				drop _all
				display "6"
				gen id=""
				display "7"
				gen testyear=.
				display "8"
				gen series=.
				display "9"
			save `list', replace
			display "10"
		}

use `main', clear
sum weight*		

display "Fixed effects weights"
*foreach w in 103 104 105 106 107 108 109 110 111 117 118 119 120 121 122 123 124 {
foreach w in 103 104 106 107 119 120 121 122 123 124 {
	egen include`w'=max(weight`w') if mom==1, by(id)
	egen weight`w'_fe=sum(weight`w') if sib+mom==0, by(id)
	replace weight`w'_fe=1 if mom==1&include`w'!=.
	drop include`w'
	}
	
sum  missing_pct* if years_rel_birth==-1&mom==1	

save "D:\Sibling Spillover\data\c_final.dta", replace
