******************************
***Florida Sibling Analysis***
***Jenni Heissel**************
***July 25, 2014**************
***Analyzing FL Data**********
******************************
******************************

***To get older sib requirement: 
use "D:\Sibling Spillover\data\b_final_oldersisreq.dta", clear
	set more off
	
sort panel testyear

xtile tertile  =pcti_first [aw=weight23], n(3)
xtile tertile24=pcti_first [aw=weight24], n(3)
xtile tertile6=pcti_first [aw=weight6], n(3)
xtile tertile7=pcti_first [aw=weight7], n(3)

gen sib_mom=0
replace sib_mom=1 if  school_year_parent!=first_school_year_parent&school_year_parent!=.
label var sib_mom "Sibling who becomes a teen mom"
tab sib sib_mom if weight23!=.

foreach var of varlist zscore pcti pct mathnpi readnpi zscore_math zscore_read pcti_replacement zscore_noreplacement zscore_replacement {	
	gen F`var'=F.`var'
	}
	label var Fpct "Test score in year t=0"
	
	tab tertile sib [aw=weight7], sum(col_degree)
	
foreach var of varlist female frl black first_school_frl first_school_black oldest col_ever col_ever_4yr col_degree col_degree_4yr {
	replace `var'=`var'*100
	}
	
***for powerpoint
*preserve
*	collapse dropout_ever sib mom, by(id)
*	tab dropout_ever if mom==0&sib==0
*	tab dropout_ever if mom==1
*	tab dropout_ever if sib==1
*restore
	
***all years
*preserve
*qui: hist years_rel_birth, start (-15) width(1) graphregion(color(white)) bgcolor(white) freq ///
*	title(Years Relative to Sister's First Birth)
*	graph export "C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\hist_years_since_birth.png", replace
*restore

**summary numbers: 
*pcti used for replacement
tab grade if pcti!=.
tab grade if pcti!=.&pct==.
displ 19546/408726
displ 8603/29152
*margins for jjc:
tab female sib if weight23!=., sum(jjc_ever)
**mean number of obs used:
sum missing_pctiL1 missing_pctiL2 missing_pctiL3 if weight23!=.
disp  3-( .20369+.2073801+.4937269 )
*R-squared review
	reg mathnp L5.readnp if grade==8&L5.grade==3
	reg readnp L5.mathnp if grade==8&L5.grade==3
	
***mean observations per grid per year
egen mean_grid_year=count(panel), by(grid testyear)
sum mean_grid_year

***for footnote:
estpost sum col_ever_4yr if mom+sib==0 [aw=weight23]

***age year variables for suest in case models have different ages (must have same # of levels)
	gen age11=(age<12)
	gen age12=(age==12)
	gen age13=(age==13)
	gen age14=(age==14)
	gen age15=(age==15)

/*
***Table 1: Descriptive Statistics
	preserve
	***keeping only within 5 years
		*keep if years_rel_birth>=-5&years_rel_birth<=0|mom+sib==0
		collapse mom sib weight* pcti_first Age15Less Age16 Age17 fullpanel_2 hasyr0 panelreq female age_at_birth age_at_birth_cont famcount oldest frl frl_mean black first_school_pcti_first mathnp_first readnp_first first_school_frl first_school_black first_school_mathnp_first first_school_readnp_first age_dif age_dif_older age_dif_1younger age_dif_2younger age_dif_3pyounger, by(id)
	eststo clear
	local variables female age_at_birth_cont famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first 
		eststo: estpost sum `variables' if mom+sib==0
		
		sort sib
		by sib: eststo: estpost sum `variables' if mom+sib!=0

		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T1_summary_stats.rtf, ///
				main(mean) aux(sd) nonum nostar b(3) replace label onecell ///
				mtitle("Families without teen birth, all" "Teen mothers" "Siblings of teen mothers" "Families without teen birth, first-observed match" "Families without teen birth, trajectory match" ) 
	restore
	
**Synthetic control options - siblings
preserve
replace age_cont=age_cont+1
replace age=age+1
	eststo clear
	eststo: reg female if sib==1&weight23==1,  vce(cluster famid)  
	foreach i in 3 19 6 7 23 24 {
	*forv i=6/7 {
		eststo: reg female sib [aw=weight`i'],  vce(cluster famid) 
		}
			esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T2_summary_stats_synthetic_sibs.rtf, ///
				se(3) scalars(p) nonum nostar b(3) replace label onecell nonotes ///
				keep(_cons) nogaps noline noobs title(female) ///
				mtitle("Teen aunts uncles" "1ST OBS" "T=-2" ///
						"IND" "IND+NBHD" "IND+FAM" "IND+FAM+NBHD") 				
					
	foreach var of varlist age famcount frl black pcti_first pctiL3 pctiL2 pctiL1 first_school_frl first_school_black first_school_pcti_first {
		eststo clear
		eststo: reg `var' if sib==1&weight23==1,  vce(cluster famid) 
	foreach i in 3 19 6 7 23 24 {
		*forv i=6/7 {
			eststo: reg `var' sib [aw=weight`i'],  vce(cluster famid) 
			}
				esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T2_summary_stats_synthetic_sibs.rtf, ///
					se(3) scalars(p) nonum nostar b(3) append label onecell nonotes ///
					keep(_cons) nogaps noline noobs nomtitle  title(`var')
				}
	eststo clear
	eststo: reg female if sib==1&weight23==1, vce(cluster famid)
	foreach i in 3 19 6 7 23 24 {
	*forv i=6/7 {
		eststo: reg female if sib==0 [aw=weight`i'],  vce(cluster famid) 
		}
			esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T2_summary_stats_synthetic_sibs.rtf, ///
				se(3) nonum nostar b(3) append  onecell nonotes ///
				drop(_cons) nogaps noline  nomtitle
restore

foreach var of varlist female frl black oldest  {
	replace `var'=`var'/100
	}
						
***Figure 1: Trend figure
*take mean by year rel to birth for sibs, match4, match8
preserve 	
	keep if years_rel_birth>=-5&years_rel_birth<0|group==3
	eststo clear
		xi: eststo: xtreg pct   yrm4 yrm3 yrm2 yrm1   					if mom==1&years_rel_birth>=-5&years_rel_birth<0|sib+mom==0, i(panel) fe vce(cluster famid)  
			gen y_moma=0
			gen y_momla=0
			gen y_momua=0
			forv a = 1/4 {
				replace y_moma =_b[yrm`a']					 if years_rel_birth==-`a'
				replace y_momla=_b[yrm`a']-1.96*_se[yrm`a']   if years_rel_birth==-`a'
				replace y_momua=_b[yrm`a']+1.96*_se[yrm`a']   if years_rel_birth==-`a'
			}
		xi: eststo: xtreg pct   yrm4 yrm3 yrm2 yrm1   	i.age			if mom==1&years_rel_birth>=-5&years_rel_birth<0|sib+mom==0, i(panel) fe vce(cluster famid)  
			gen y_mom=0
			gen y_moml=0
			gen y_momu=0
			forv a = 1/4 {
				replace y_mom =_b[yrm`a']					 if years_rel_birth==-`a'
				replace y_moml=_b[yrm`a']-1.96*_se[yrm`a']   if years_rel_birth==-`a'
				replace y_momu=_b[yrm`a']+1.96*_se[yrm`a']   if years_rel_birth==-`a'
			}
		xi: eststo: xtreg pct   yrm4 yrm3 yrm2 yrm1  	i.age i.schnum	if mom==1&years_rel_birth>=-5&years_rel_birth<0|sib+mom==0, i(panel) fe vce(cluster famid)  
		xi: eststo: xtreg pct   yrm4 yrm3 yrm2 yrm1   					if sib==1&years_rel_birth>=-5&years_rel_birth<0|sib+mom==0, i(panel) fe vce(cluster famid)  
			gen y_siba=0
			gen y_sibla=0
			gen y_sibua=0
			forv a = 1/4 {
				replace y_siba =_b[yrm`a']					 if years_rel_birth==-`a'
				replace y_sibla=_b[yrm`a']-1.96*_se[yrm`a']   if years_rel_birth==-`a'
				replace y_sibua=_b[yrm`a']+1.96*_se[yrm`a']   if years_rel_birth==-`a'
			}
		xi: eststo: xtreg pct  yrm4 yrm3 yrm2 yrm1   	i.age			if sib==1&years_rel_birth>=-5&years_rel_birth<0|sib+mom==0, i(panel) fe vce(cluster famid)  
			gen y_sib=0
			gen y_sibl=0
			gen y_sibu=0
			forv a = 1/4 {
				replace y_sib =_b[yrm`a']					 if years_rel_birth==-`a'
				replace y_sibl=_b[yrm`a']-1.96*_se[yrm`a']   if years_rel_birth==-`a'
				replace y_sibu=_b[yrm`a']+1.96*_se[yrm`a']   if years_rel_birth==-`a'
			}
		xi: eststo: xtreg pct  yrm4 yrm3 yrm2 yrm1  	i.age i.schnum	if sib==1&years_rel_birth>=-5&years_rel_birth<0|sib+mom==0, i(panel) fe vce(cluster famid)  
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA1_pretrends.rtf, ///
			title(For variable: pcti)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			scalar(N_g) sfmt(0) nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			mtitles("Moms" "Moms Age FE" "Moms Age & School FE" "Sibs" "Sibs Age FE" "Sibs Age & School FE") ///
			drop (_Iage* _Ischnum* _cons) ///
			addnotes(Includes age FE on second model, age & school FE on third model)
		eststo clear
	replace years_rel_birth = years_rel_birth-.05 if sib==1
	replace years_rel_birth = years_rel_birth+.05 if mom==1	
	twoway 		(connected y_siba years_rel_birth 			if sib==1, sort			lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black))  ///
				(rcap      y_sibla y_sibua years_rel_birth	if sib==1, sort			lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y_moma years_rel_birth			if mom==1, sort			lwidth(medthick) lcolor(gray ) lpattern(dash) mcolor(gray))  ///
				(rcap      y_momla y_momua years_rel_birth	if mom==1, sort			lwidth(medthick) lcolor(gray ) lpattern(solid) mcolor(gray)),  ///
				legend (order(1 "Teen aunts/uncles" 3 "Teen mothers")) yline(0) ///
				ytitle(Change in percentile scores) xtitle(Time until birth) title(A. Individual Fixed effects) graphregion(color(white)) name(panela, replace)
	twoway 		(connected y_sib years_rel_birth 			if sib==1, sort			lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black))  ///
				(rcap      y_sibl y_sibu years_rel_birth	if sib==1, sort			lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y_mom years_rel_birth			if mom==1, sort			lwidth(medthick) lcolor(gray ) lpattern(dash) mcolor(gray))  ///
				(rcap      y_moml y_momu years_rel_birth	if mom==1, sort			lwidth(medthick) lcolor(gray ) lpattern(solid) mcolor(gray)),  ///
				legend (order(1 "Teen aunts/uncles" 3 "Teen mothers")) yline(0) ///
				ytitle(Change in percentile scores) xtitle(Time until birth) title(B. Plus age fixed effects) graphregion(color(white)) name(panelb, replace)
	grc1leg panela panelb, graphregion(color(white)) ycommon
	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F1_pretrends.png, replace
	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F1_pretrends.emf, replace

restore
		
***Figure 4: Trend+Outcomes figure for dropout- siblings
preserve
	foreach w in 3 6 7 19 23 24 {
		use "D:\Sibling Spillover\data\OlderSibReq\b_years_rel_birth_`w'", clear
		gen lastyear=0
		replace lastyear=100 if dropout_year==testyear
		egen include2 =count(panel) if years_rel_birth==0|years_rel_birth==1, by(id)
		tab include2, m
		replace include2=1 if include2>0&include2!=.
		keep if years_rel_birth>=-4&years_rel_birth<=1&weight`w'_rel>0&weight`w'_rel!=.
		gen belowage16=1
		replace belowage16=0 if age<16
		gen sib_yrm5=sib*yrm5
		gen sib_yrm4=sib*yrm4
		gen sib_yrm3=sib*yrm3
		gen sib_yrm2=sib*yrm2
		gen sib_yrm1=sib*yrm1
		gen sib_yr0=sib*yr0
		gen sib_yr1=sib*yr1
		gen sib_yr2=sib*yr2
		gen sib_yr3=sib*yr3
		gen sib_yr4=sib*yr4
		foreach var of varlist lastyear 	{
			gen y`w'=0
			gen yl`w'=0
			gen yu`w'=0
			forv i=0/1 {
				***can add belowage16 - the age they can drop out.  age FE bad b/c once they drop out, they're out of the data.  
				xi: eststo: xtreg `var'  yrm3 yrm2 yrm1 yr0  yr1 sib_yrm3 sib_yrm2 sib_yrm1 sib_yr0 sib_yr1 sib_yr2  [aw=weight`w'_rel], i(panel) fe vce(cluster famid)  
		forv a = 1/3 {
				replace y`w' =_b[yrm`a']					 	if years_rel_birth==-`a'&sib==0
				replace yl`w'=_b[yrm`a']-1.96*_se[yrm`a']   	if years_rel_birth==-`a'&sib==0
				replace yu`w'=_b[yrm`a']+1.96*_se[yrm`a']   	if years_rel_birth==-`a'&sib==0
				replace y`w' =_b[yrm`a']+_b[sib_yrm`a']		 	if years_rel_birth==-`a'&sib==1
				replace yl`w'=_b[yrm`a']+_b[sib_yrm`a']-1.96*_se[sib_yrm`a']	if years_rel_birth==-`a'&sib==1
				replace yu`w'=_b[yrm`a']+_b[sib_yrm`a']+1.96*_se[sib_yrm`a']   	if years_rel_birth==-`a'&sib==1
					}
			forv a = 0/1 {
				replace y`w' =_b[yr`a']					 	if years_rel_birth==`a'&sib==0
				replace yl`w'=_b[yr`a']-1.96*_se[yr`a']   	if years_rel_birth==`a'&sib==0
				replace yu`w'=_b[yr`a']+1.96*_se[yr`a']   		if years_rel_birth==`a'&sib==0
				replace y`w' =_b[yr`a']+_b[sib_yr`a']		 	if years_rel_birth==`a'&sib==1
				replace yl`w'=_b[yr`a']+_b[sib_yr`a']-1.96*_se[sib_yr`a']	if years_rel_birth==`a'&sib==1
				replace yu`w'=_b[yr`a']+_b[sib_yr`a']+1.96*_se[sib_yr`a']   	if years_rel_birth==`a'&sib==1
					}
				}	
			}
			collapse y`w' yl`w' yu`w', by(years_rel_birth sib)
			tempfile tempfig`w'
			save `tempfig`w'', replace
		}
	merge 1:1 years_rel_birth sib using `tempfig3' 	
	drop _merge
	merge 1:1 years_rel_birth sib using `tempfig6' 	
	drop _merge
	merge 1:1 years_rel_birth sib using `tempfig7' 	
	drop _merge
	merge 1:1 years_rel_birth sib using `tempfig19' 	
	drop _merge
	merge 1:1 years_rel_birth sib using `tempfig23' 	
	replace years_rel_birth=years_rel_birth-.05
	replace years_rel_birth=years_rel_birth+.1 if sib==0
	twoway 		(connected y23 years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(rcap      yl23 yu23 years_rel_birth	if sib==1, sort			lwidth(medthick) lcolor(black) lpattern(solid) ) ///
				(connected y23 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(dash) mcolor(gray)) ///
				(rcap      yl23 yu23 years_rel_birth	if sib==0, sort			lwidth(medthick) lcolor(gray) lpattern(dash) ) ///
				(connected y24 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(solid) mcolor(gray)) ///
				(rcap      yl24 yu24 years_rel_birth	if sib==0, sort			lwidth(medthick) lcolor(gray) lpattern(solid) ) ///
				,  ///
				xline(-1.5) legend(cols(1) order( 1 "Teen aunts/uncles" 3 "IND+FAM" 5 "IND+FAM+NBHD")) ///
				ytitle(Percent dropout by year) xtitle(Time until birth) graphregion(color(white)) ///
				title(B. Trajectory matches) name(trajectory, replace)
	twoway 		(connected y19 years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(rcap      yl19 yu19 years_rel_birth	if sib==1, sort			lwidth(medthick) lcolor(black) lpattern(solid) ) ///
				(connected y3 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(dash) mcolor(gray)) ///
				(rcap      yl3 yu3 years_rel_birth	if sib==0, sort			lwidth(medthick) lcolor(gray) lpattern(dash) ) ///
				(connected y19 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(solid) mcolor(gray)) ///
				(rcap      yl19 yu19 years_rel_birth	if sib==0, sort			lwidth(medthick) lcolor(gray) lpattern(solid) ) ///
				,  ///
				xline(-1.5) legend(cols(1) order(1 "Teen aunts/uncles" 3 "1ST OBS" 5 "T=-2")) ///
				ytitle(Percent dropout by year) xtitle(Time until birth) graphregion(color(white)) ///
				title(A. One-time matches) name(onetime, replace)
	graph combine onetime trajectory, graphregion(color(white)) ycommon
	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F4_dropout.png, replace
	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F4_dropout.emf, replace

restore

****Figure 5: Lowess options
preserve
label variable Fpct				"A. Test score in year t=0"
label variable Fzscore			"A. Test score in year t=0"
label variable repeat_later 	"B. Repeats grade"
label variable dropout 			"C. Drops out"
label variable jjc	 			"D. Juvenile Justice"
label variable col_ever 		"E. Attends any college"
label variable col_degree 		"F. Any college degree"
label variable col_degree_4yr 	"F. 4-year college degree"
foreach var of varlist Fpct repeat_later dropout jjc col_ever col_degree col_degree_4yr {
	sum `var' [aw=weight7] if sib==1
	local mean_sib =r(mean)
	sum `var' [aw=weight7] if sib==0
	local mean_match =r(mean)

	sum pcti_first [aw=weight7] if tertile==1
	local tertile1 =r(max)
	sum pcti_first [aw=weight7] if tertile==2
	local tertile2 =r(max)
		
		local vtext : variable label `var'
		if `"`vtext'"' == "" local vtext "`var'" 

		twoway 	(lowess `var' pcti_first if sib==1&weight7!=., lcolor(black) lpattern(solid) lwidth(thick)) ///
				(lowess `var' pcti_first if sib==0&weight7!=., lcolor(gray)  lpattern(dash) lwidth(thick)), ///
			yline(`mean_sib',   lcolor(black) lpattern(solid) ) ///
			yline(`mean_match', lcolor(gray) lpattern(dash)  ) ///
			xline(`tertile1', lcolor(gs12) lpattern(solid)  ) ///
			xline(`tertile2', lcolor(gs12) lpattern(solid)  ) ///
			legend(order( 1 "Siblings" 2 "Ind. & fam. trajectory match")) ///
			ytitle("") xtitle(Score at baseline) graphregion(color(white)) ///
			title(`"`vtext'"') name(`var', replace)
			}
		grc1leg Fpct repeat_later dropout jjc col_ever col_degree,  graphregion(color(white))
		graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F5_lowess_sibs.png, replace		
		graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F5_lowess_sibs.emf, replace		
restore	
graph drop _all

**************************************************
******************TABLES**************************
**************************************************
**************************
***SIBLINGS***
**************************			
***PLACEBO
***Table 10: Placebo
	eststo clear
	***Variable "jjc" tells me if they are in JJC that year OR LATER - so must use other JJC variable
	foreach var of varlist L.pct L.repeat L.dropout_before L.jjc_before  {
		eststo: reg `var' sib female i.age famcount oldest frl black hispanic pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight7], vce(cluster famid)
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T10_sibling_outcomes_placebo_before.rtf, ///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			nonotes keep(sib)	

			*/
***Table 3: Estimated Effects - SIBLINGS
**ROW 1: Test scores in t=-1
	eststo clear
	eststo: reg pct sib female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first  if years_rel_birth==-1&sib==1|sib+mom==0&seq==7, vce(cluster famid)
	eststo: reg pct sib female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first [aw=weight3], vce(cluster famid)
	eststo: reg pct sib female i.age famcount oldest frl black pctiL1		 first_school_frl first_school_black first_school_pcti_first [aw=weight19], vce(cluster famid)
	eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight6], vce(cluster famid)
	eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight7], vce(cluster famid)
	eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight23], vce(cluster famid)
	eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight24], vce(cluster famid)
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T3_sibling_outcomes.rtf, ///
			title(Percentile rank - test score before birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			mtitles("OLS" "1STOBS" "T=-2" "IND" "IND+NBHD" "IND+FAM" "IND+FAM+NBHD") ///
			keep(sib) nonotes 
**ROW 2: Test scores in t=0
	eststo clear
	eststo: reg F.pct sib female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first  if years_rel_birth==-1&sib==1|sib+mom==0&seq==7, vce(cluster famid)
	eststo: reg F.pct sib female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first [aw=weight3], vce(cluster famid)
	eststo: reg F.pct sib female i.age famcount oldest frl black pctiL1	   first_school_frl first_school_black first_school_pcti_first [aw=weight19], vce(cluster famid)
	eststo: reg F.pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight6], vce(cluster famid)
	eststo: reg F.pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight7], vce(cluster famid)
	eststo: reg F.pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight23], vce(cluster famid)
	eststo: reg F.pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight24], vce(cluster famid)
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T3_sibling_outcomes.rtf, ///
			title(Percentile rank - test score after birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes 
**ROW 3: FE
	eststo clear
	eststo: xtreg pct sib_on  i.age female     famcount oldest frl black pcti_first  if mom==0&years_rel_birth!=-1, i(panel) fe  vce(cluster famid)
	***include age and school FE?
	eststo: xtreg pct sib_on  i.age female     famcount oldest frl black pcti_first  if mom==0&years_rel_birth!=-1 [aw=weight3_fe], i(panel) fe  vce(cluster famid)
	eststo: xtreg pct sib_on  i.age female     famcount oldest frl black pcti_first  if mom==0&years_rel_birth!=-1 [aw=weight19_fe], i(panel) fe  vce(cluster famid)
	eststo: xtreg pct sib_on  i.age female     famcount oldest frl black pcti_first  if mom==0&years_rel_birth!=-1 [aw=weight6_fe], i(panel) fe  vce(cluster famid)
	eststo: xtreg pct sib_on  i.age female     famcount oldest frl black pcti_first  if mom==0&years_rel_birth!=-1 [aw=weight7_fe], i(panel) fe  vce(cluster famid)
	eststo: xtreg pct sib_on  i.age female     famcount oldest frl black pcti_first  if mom==0&years_rel_birth!=-1 [aw=weight23_fe], i(panel) fe  vce(cluster famid)
	eststo: xtreg pct sib_on  i.age female     famcount oldest frl black pcti_first  if mom==0&years_rel_birth!=-1 [aw=weight24_fe], i(panel) fe  vce(cluster famid)
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T3_sibling_outcomes.rtf, ///
			title(Test scores, with age and individual FE)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			scalar(N_g) sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib_on) nonotes 
**ROW 4: Repeat and up
foreach var of varlist repeat_later dropout jjc col_ever col_degree col_degree_4yr {
	eststo clear
	eststo: reg `var' sib female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first  if years_rel_birth==-1&sib==1|sib+mom==0&seq==7, vce(cluster famid)
	eststo: reg `var' sib female i.age famcount oldest frl black pcti_first first_school_frl first_school_black first_school_pcti_first [aw=weight3], vce(cluster famid)
	eststo: reg `var' sib female i.age famcount oldest frl black pctiL1  	first_school_frl first_school_black first_school_pcti_first [aw=weight19], vce(cluster famid)
	eststo: reg `var' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight6], vce(cluster famid)
	eststo: reg `var' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight7], vce(cluster famid)
	eststo: reg `var' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight23], vce(cluster famid)
	eststo: reg `var' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight24], vce(cluster famid)
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T3_sibling_outcomes.rtf, ///
			title(`var')	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes 
			}
/*
***Table 4: Estimated Effects by Subgroups
**ROW 1: Test scores in t=-1
	eststo clear
	eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight7], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if `var'==`i' [aw=weight7], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T4_sibling_outcomes_groups.rtf, ///
			title(Percentile rank - test score before birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			mtitles("All" "Female" "Male" "Black" "Non-black" "FRL" "Non-FRL") ///
			keep(sib) nonotes 
**ROW 2: Test scores in t=0
	eststo clear
	eststo: reg Fpct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight7], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {	
			eststo: reg Fpct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i'  [aw=weight7], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T4_sibling_outcomes_groups.rtf, ///
			title(Percentile rank - test score after birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes 
**ROW 3: FE
	eststo clear
	eststo: xtreg pct sib_on  i.age female     famcount oldest frl black pcti_first if years_rel_birth!=-1  [aw=weight23_fe], i(panel) fe  vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: xtreg pct sib_on  i.age female     famcount oldest frl black pcti_first  if `var'==`i'&years_rel_birth!=-1  [aw=weight7_fe], i(panel) fe  vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T4_sibling_outcomes_groups.rtf, ///
			title(Test scores, with age and individual FE)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			scalar(N_g) sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib_on) nonotes 
**ROW 4 and up
foreach outcome of varlist repeat_later dropout jjc col_ever col_degree col_degree_4yr {
	eststo clear
	eststo: reg `outcome' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight23], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: reg `outcome' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i' [aw=weight7], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T4_sibling_outcomes_groups.rtf, ///
			title(`outcome')	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes 
			}
***Table 4: Estimated Effects by Subgroups - IND+FAM+NBHD Appendix
**ROW 1: Test scores in t=-1
	eststo clear
	eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight24], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if `var'==`i' [aw=weight24], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_INDFAMNBHD.rtf, ///
			title(Percentile rank - test score before birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			mtitles("All" "Female" "Male" "Black" "Non-black" "FRL" "Non-FRL") ///
			keep(sib) nonotes 
**ROW 2: Test scores in t=0
	eststo clear
	eststo: reg Fpct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight24], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {	
			eststo: reg Fpct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i'  [aw=weight24], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_INDFAMNBHD.rtf, ///
			title(Percentile rank - test score after birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes 
**ROW 3: FE
	eststo clear
	eststo: xtreg pct sib_on  i.age female    if years_rel_birth!=-1  [aw=weight24_fe], i(panel) fe  vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: xtreg pct sib_on  i.age  if `var'==`i'&years_rel_birth!=-1  [aw=weight24_fe], i(panel) fe  vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_INDFAMNBHD.rtf, ///
			title(Test scores, with age and individual FE)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			scalar(N_g) sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib_on) nonotes 
**ROW 4 and up
foreach outcome of varlist repeat_later dropout jjc col_ever col_degree col_degree_4yr {
	eststo clear
	eststo: reg `outcome' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight24], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: reg `outcome' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i' [aw=weight24], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_INDFAMNBHD.rtf, ///
			title(`outcome')	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes 
			}
***Table 4: Estimated Effects by Subgroups - IND Appendix
**ROW 1: Test scores in t=-1
	eststo clear
	eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight6], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if `var'==`i' [aw=weight6], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_IND.rtf, ///
			title(Percentile rank - test score before birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			mtitles("All" "Female" "Male" "Black" "Non-black" "FRL" "Non-FRL") ///
			keep(sib) nonotes 
**ROW 2: Test scores in t=0
	eststo clear
	eststo: reg Fpct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight6], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {	
			eststo: reg Fpct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i'  [aw=weight6], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_IND.rtf, ///
			title(Percentile rank - test score after birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes 
**ROW 3: FE
	eststo clear
	eststo: xtreg pct sib_on  i.age female    if years_rel_birth!=-1  [aw=weight6_fe], i(panel) fe  vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: xtreg pct sib_on  i.age  if `var'==`i'&years_rel_birth!=-1  [aw=weight6_fe], i(panel) fe  vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_IND.rtf, ///
			title(Test scores, with age and individual FE)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			scalar(N_g) sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib_on) nonotes 
**ROW 4 and up
foreach outcome of varlist repeat_later dropout jjc col_ever col_degree col_degree_4yr {
	eststo clear
	eststo: reg `outcome' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight6], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: reg `outcome' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i' [aw=weight6], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_IND.rtf, ///
			title(`outcome')	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes 
			}
***Table 4: Estimated Effects by Subgroups - IND+NBHD Appendix
**ROW 1: Test scores in t=-1
	eststo clear
	eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight7], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: reg pct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if `var'==`i' [aw=weight7], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_INDNBHD.rtf, ///
			title(Percentile rank - test score before birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			mtitles("All" "Female" "Male" "Black" "Non-black" "FRL" "Non-FRL") ///
			keep(sib) nonotes 
**ROW 2: Test scores in t=0
	eststo clear
	eststo: reg Fpct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight7], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {	
			eststo: reg Fpct sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i'  [aw=weight7], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_INDNBHD.rtf, ///
			title(Percentile rank - test score after birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes 
**ROW 3: FE
	eststo clear
	eststo: xtreg pct sib_on  i.age female    if years_rel_birth!=-1  [aw=weight24_fe], i(panel) fe  vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: xtreg pct sib_on  i.age  if `var'==`i'&years_rel_birth!=-1  [aw=weight24_fe], i(panel) fe  vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_INDNBHD.rtf, ///
			title(Test scores, with age and individual FE)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			scalar(N_g) sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib_on) nonotes 
**ROW 4 and up
foreach outcome of varlist repeat_later dropout jjc col_ever col_degree col_degree_4yr {
	eststo clear
	eststo: reg `outcome' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight7], vce(cluster famid)
	foreach var of varlist female black frl {	
		forv i=1(-1)0 {
			eststo: reg `outcome' sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i' [aw=weight7], vce(cluster famid)
			}
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA5_sibling_outcomes_groups_INDNBHD.rtf, ///
			title(`outcome')	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes 
			}
			
***Table 5: Sibling results by tertile
**ROW 1: Test scores in t=-1
	eststo clear
		forv i=1/3 {
			eststo modelmain`i': 	reg pct sib female age1* famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if tertile==`i' [aw=weight7], vce(cluster famid)
									reg pct sib female age1* famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if tertile==`i' [aw=weight7]
									est store model`i'
			}
			suest model1 model2 model3, vce(cluster famid)
			test [model1_mean]sib=[model2_mean]sib=[model3_mean]sib
			estadd scalar test=r(p): modelmain2

		esttab modelmain1 modelmain2 modelmain3 using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T5_sibling_outcomes_tertile.rtf, ///
			title(Percentile rank - test score before birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			mtitles("Tertile 1" "Tertile 2" "Tertile 3") ///
			keep(sib) nonotes  stats(N test, fmt(0 3))
**ROW 2: Test scores in t=0
foreach outcome of varlist Fpct repeat_later dropout jjc col_ever col_degree col_degree_4yr {
	eststo clear
		forv i=1/3 {	
			eststo modelmain`i': 	reg `outcome' sib female age1* famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if tertile6==`i' [aw=weight6], vce(cluster famid)
									reg `outcome' sib female age1* famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if tertile6==`i' [aw=weight6]
									est store model`i'
			}
			suest model1 model2 model3, vce(cluster famid)
			test [model1_mean]sib=[model2_mean]sib=[model3_mean]sib
			estadd scalar test=r(p): modelmain2

		esttab modelmain1 modelmain2 modelmain3 using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T5_sibling_outcomes_tertile.rtf, ///
			title(`outcome')	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes  stats(N test, fmt(0 3))
			}
**ROW 2: Test scores in t=0
foreach outcome of varlist pct Fpct repeat_later dropout jjc col_ever col_degree col_degree_4yr {
	eststo clear
		forv i=1/3 {	
			eststo modelmain`i': 	reg `outcome' sib female age1* famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if tertile7==`i' [aw=weight7], vce(cluster famid)
									reg `outcome' sib female age1* famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if tertile7==`i' [aw=weight7]
									est store model`i'
			}
			suest model1 model2 model3, vce(cluster famid)
			test [model1_mean]sib=[model2_mean]sib=[model3_mean]sib
			estadd scalar test=r(p): modelmain2

		esttab modelmain1 modelmain2 modelmain3 using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T5_sibling_outcomes_tertile.rtf, ///
			title(`outcome' - IND+FAM+NBHD)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib) nonotes  stats(N test, fmt(0 3))
			}
 tab tertile, sum(col_ever)
 
***Table 8, Panel A: Estimated Effects - SIBLINGS WHO BECOME TEEN MOMS
eststo clear
***only have one obs per treated at birth=0 - what about for controls?
foreach var of varlist Fpct repeat_later dropout jjc col_ever col_degree col_degree_4yr {
		eststo: reg `var' sib sib_mom female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if female==1 [aw=weight7], vce(cluster famid)
			test _b[sib]+_b[sib_mom]=0
			estadd scalar test=r(p)
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T8_sibling_outcomes_becomemoms.rtf, ///
			title(Percentile rank - test score before birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			keep(sib sib_mom) nonotes stats(N test, fmt(0 3))
			}		
			
***Table 8, Panels B-C: Estimated Effects by different family compsitions
	eststo clear
	foreach var of varlist Fpct repeat_later dropout jjc col_ever col_degree col_degree_4yr {
		eststo: reg `var' sib has_sis has_bro female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first [aw=weight7], vce(cluster famid)
			test _b[has_bro]=_b[has_sis]=0
			estadd scalar test=r(p)
			test _b[has_bro]=_b[has_sis]
			estadd scalar test2=r(p)		
				}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T8_sibling_outcomes_composition.rtf, ///
			title(Percentile rank - test score after birth)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			keep(sib has_bro has_sis ) nonotes  stats(N test test2, fmt(0 3 3))

	eststo clear
	foreach var of varlist Fpct repeat_later dropout jjc col_ever col_degree col_degree_4yr {
		eststo: reg `var' sib has_sis has_bro female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if female==1 [aw=weight7], vce(cluster famid)
			test _b[has_bro]=_b[has_sis]=0
			estadd scalar test=r(p)
			test _b[has_bro]=_b[has_sis]
			estadd scalar test2=r(p)	
				}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T8_sibling_outcomes_composition.rtf, ///
			title(Percentile rank - test score after birth sisters only)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nomtitles ///
			keep(sib has_bro has_sis ) nonotes  stats(N test test2, fmt(0 3))
			
***Table 8, Panel D: IV regressions
	eststo clear
	foreach var of varlist Fpct repeat_later dropout jjc col_ever col_degree col_degree_4yr {
		eststo: ivreg2 `var' female i.age famcount frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first (sib4=sib3) [aw=weight7],  cluster(famid) first
		mat fstat = r(singleresults)
		estadd scalar fs = fstat[1,4]
		}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\T8_sibling_outcomes_iv.rtf, ///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			sfmt(0) nocons compress  append b(3) se(3)  nonumbers   label onecell ///
			nonotes  stats(N fs, fmt(0 0))	title(Siblings)		
			
***Table AT3: Descriptive Statistics for control
	preserve
	eststo clear
	sort panel testyear
	local variables pct Fpct repeat_later dropout jjc col_ever col_degree col_degree_4yr
		eststo: estpost sum `variables' if mom+sib==0 [aw=weight7]
		foreach var of varlist male black frl {
			sort `var'
			by `var': eststo: estpost sum `variables' if mom+sib==0 [aw=weight7]
			}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA3a_summary_stats.rtf, ///
				main(mean) aux(sd) nonum nostar b(3) replace label onecell ///
				mtitle("All" "Female" "Male" "Non-black" "Black" "Non-FRL" "FRL") 
	restore			
				
***Test if year m1 differs
	eststo clear

	foreach i in 6 7 23 24 {
	preserve
		use "D:\Sibling Spillover\data\OlderSibReq\b_years_rel_birth_`i'", clear
		gen sib_age=sib*age
		gen sib_yrm5=sib*yrm5
		gen sib_yrm4=sib*yrm4
		gen sib_yrm3=sib*yrm3
		gen sib_yrm2=sib*yrm2
		gen sib_yrm1=sib*yrm1
		gen sib_yrm0=sib*yrm0
		gen sib_yr1=sib*yr1
			keep if years_rel_birth>=-4&years_rel_birth<=1
		egen temp =count(panel) if years_rel_birth==0|years_rel_birth==1, by(id)
		tab temp, m
		replace temp=1 if temp>0&temp!=.
		egen include2=max(temp), by(id)
		xi: eststo: xtreg pct  yrm3 yrm2 yrm1 yrm0  yr1  sib_yrm3 sib_yrm2 sib_yrm1 sib_yrm0 sib_yr1 i.age if include2==1  [aw=weight`i'_rel], i(panel) fe vce(cluster famid)  

	restore 
	}
		esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TA4_testt1.rtf, ///
			title(Test scores, with age and individual FE)	///
			star(+ 0.10 * 0.05 ** 0.01 *** 0.001) ///
			nocons compress  replace b(3) se(3)  nonumbers   label onecell ///
			mtitles("Sibs IND+FAM" "Sib IND+FAM+NBHD") ///
			nonotes drop(_Iage* ) scalar(N_g) sfmt(0) 
*/
***FIGURE 3, FIGURE 6, FIGURE FA1 - 
**All
eststo clear
preserve
	foreach w in 2 {
		gen grade8=0
		replace grade8=1 if grade==8
		gen grade10=0
		replace grade10=1 if grade==10
			gen y`w'=0
			gen yl`w'=0
			gen yu`w'=0
			keep if years_rel_birth>=-4&years_rel_birth<=1&sib==1|sib+mom==0
			egen temp =count(panel) if years_rel_birth==0|years_rel_birth==1, by(id)
			*egen temp =count(panel) if years_rel_birth==0, by(id)
			tab temp, m
			replace temp=1 if temp>0&temp!=.
		egen include2=max(temp), by(id)
		gen include=1
			xi: eststo: xtreg pct  yrm3 yrm2 yrm1 yr0  yr1  i.age  if include2==1&sib==1|sib+mom==0, i(panel) fe vce(cluster famid)  
				forv a = 1/3 {
					replace y`w' =_b[yrm`a']					 	if years_rel_birth==-`a'&sib==1
					replace yl`w'=_b[yrm`a']-1.96*_se[yrm`a']   	if years_rel_birth==-`a'&sib==1
					replace yu`w'=_b[yrm`a']+1.96*_se[yrm`a']   		if years_rel_birth==-`a'&sib==1
						}
				forv a = 0/1 {
					replace y`w' =_b[yr`a']							if years_rel_birth==`a'&sib==1
					replace yl`w'=_b[yr`a']-1.96*_se[yr`a']    		if years_rel_birth==`a'&sib==1
					replace yu`w'=_b[yr`a']+1.96*_se[yr`a']    		if years_rel_birth==`a'&sib==1
						}
				collapse y`w' yl`w' yu`w', by(years_rel_birth sib)
				tempfile tempfig`w'
				save `tempfig`w'', replace
			
				collapse y`w' yl`w' yu`w', by(years_rel_birth sib)
				tempfile tempfig`w'
				save `tempfig`w'', replace
				}

**matches: 
eststo clear
	foreach w in 3 4 19 20 6 7 23 24 25 26 27 28 {
		use "D:\Sibling Spillover\data\OlderSibReq\b_years_rel_birth_`w'", clear
		gen grade8=0
		replace grade8=1 if grade==8
		gen grade10=0
		replace grade10=1 if grade==10
		gen sib_yrm5=sib*yrm5
		gen sib_yrm4=sib*yrm4
		gen sib_yrm3=sib*yrm3
		gen sib_yrm2=sib*yrm2
		gen sib_yrm1=sib*yrm1
		gen sib_yr0=sib*yr0
		gen sib_yr1=sib*yr1
			gen y`w'=0
			gen yl`w'=0
			gen yu`w'=0
			keep if years_rel_birth>=-4&years_rel_birth<=1
			egen temp =count(panel) if years_rel_birth==0|years_rel_birth==1, by(id2)
			*egen temp =count(panel) if years_rel_birth==0, by(id2)
			tab temp, m
			replace temp=1 if temp>0&temp!=.
		egen include2=max(temp), by(id)
		gen include=1
			if  `w'==19|`w'==20 {		
			xi: eststo: xtreg pct  yrm4 yrm3 yrm1 yr0  yr1 sib_yrm4 sib_yrm3 sib_yrm1 sib_yr0 sib_yr1 i.age if include2==1 [aw=weight`w'_rel], i(panel) fe vce(cluster famid)  
				test sib_yr0=sib_yr1=0
				tempvar adjust6 
				gen adjust6=-_b[yrm4] - _b[sib_yrm4] 
				*gen adjust6=0
				foreach  a in 1 3 4 {
					replace y`w' =_b[yrm`a']+adjust6					 	if years_rel_birth==-`a'&sib==0
					replace yl`w'=_b[yrm`a']-1.96*_se[yrm`a']+adjust6   	if years_rel_birth==-`a'&sib==0
					replace yu`w'=_b[yrm`a']+1.96*_se[yrm`a']+adjust6   		if years_rel_birth==-`a'&sib==0
					replace y`w' =_b[yrm`a']+_b[sib_yrm`a']+adjust6		 	if years_rel_birth==-`a'&sib==1
					replace yl`w'=_b[yrm`a']+_b[sib_yrm`a']-1.96*_se[sib_yrm`a']+adjust6	if years_rel_birth==-`a'&sib==1
					replace yu`w'=_b[yrm`a']+_b[sib_yrm`a']+1.96*_se[sib_yrm`a']+adjust6   	if years_rel_birth==-`a'&sib==1
						}
				foreach a in 2 {
					replace y`w' =adjust6					 	if years_rel_birth==-`a'&sib==0
					replace yl`w'=adjust6   	if years_rel_birth==-`a'&sib==0
					replace yu`w'=adjust6   		if years_rel_birth==-`a'&sib==0
					replace y`w' =adjust6		 	if years_rel_birth==-`a'&sib==1
					replace yl`w'=adjust6	if years_rel_birth==-`a'&sib==1
					replace yu`w'=adjust6   	if years_rel_birth==-`a'&sib==1
						}
				forv a = 0/1 {
					replace y`w' =_b[yr`a']+adjust6							if years_rel_birth==`a'&sib==0
					replace yl`w'=_b[yr`a']-1.96*_se[yr`a']+adjust6    		if years_rel_birth==`a'&sib==0
					replace yu`w'=_b[yr`a']+1.96*_se[yr`a']+adjust6    		if years_rel_birth==`a'&sib==0
					replace y`w' =_b[yr`a']+_b[sib_yr`a']+adjust6				if years_rel_birth==`a'&sib==1
					replace yl`w'=_b[yr`a']+_b[sib_yr`a']-1.96*_se[sib_yr`a']+adjust6		if years_rel_birth==`a'&sib==1
					replace yu`w'=_b[yr`a']+_b[sib_yr`a']+1.96*_se[sib_yr`a']+adjust6    	if years_rel_birth==`a'&sib==1
						}
				tab years_rel_birth sib, sum(y`w')
			}
			else {
			xi: eststo: xtreg pct  yrm3 yrm2 yrm1 yr0  yr1  sib_yrm3 sib_yrm2 sib_yrm1 sib_yr0 sib_yr1 i.age  if include2==1 [aw=weight`w'_rel], i(panel) fe vce(cluster famid)  
				test sib_yr0=sib_yr1=0
				forv a = 1/3 {
					replace y`w' =_b[yrm`a']					 	if years_rel_birth==-`a'&sib==0
					replace yl`w'=_b[yrm`a']-1.96*_se[yrm`a']   	if years_rel_birth==-`a'&sib==0
					replace yu`w'=_b[yrm`a']+1.96*_se[yrm`a']   		if years_rel_birth==-`a'&sib==0
					replace y`w' =_b[yrm`a']+_b[sib_yrm`a']		 	if years_rel_birth==-`a'&sib==1
					replace yl`w'=_b[yrm`a']+_b[sib_yrm`a']-1.96*_se[sib_yrm`a']	if years_rel_birth==-`a'&sib==1
					replace yu`w'=_b[yrm`a']+_b[sib_yrm`a']+1.96*_se[sib_yrm`a']   	if years_rel_birth==-`a'&sib==1
						}
				forv a = 0/1 {
					replace y`w' =_b[yr`a']							if years_rel_birth==`a'&sib==0
					replace yl`w'=_b[yr`a']-1.96*_se[yr`a']    		if years_rel_birth==`a'&sib==0
					replace yu`w'=_b[yr`a']+1.96*_se[yr`a']    		if years_rel_birth==`a'&sib==0
					replace y`w' =_b[yr`a']+_b[sib_yr`a']			if years_rel_birth==`a'&sib==1
					replace yl`w'=_b[yr`a']+_b[sib_yr`a']-1.96*_se[sib_yr`a']		if years_rel_birth==`a'&sib==1
					replace yu`w'=_b[yr`a']+_b[sib_yr`a']+1.96*_se[sib_yr`a']    	if years_rel_birth==`a'&sib==1
						}
				collapse y`w' yl`w' yu`w', by(years_rel_birth sib)
				tempfile tempfig`w'
				save `tempfig`w'', replace
			}
			
				collapse y`w' yl`w' yu`w', by(years_rel_birth sib)
				tempfile tempfig`w'
				save `tempfig`w'', replace
				}
	foreach w in 2 3 4 19 20 6 7 23 24 25 26 27  {
		merge 1:1 years_rel_birth sib using `tempfig`w''
		drop _merge
	}
	replace years_rel_birth=years_rel_birth-.05
	replace years_rel_birth=years_rel_birth+.1 if sib==0
	twoway 		(connected y7 years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(rcap      yl7 yu7 years_rel_birth	if sib==1, sort			lwidth(medthick) lcolor(black) lpattern(solid) ) ///
				(connected y4 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(dash) mcolor(gray)) ///
				(rcap      yl4 yu4 years_rel_birth	if sib==0, sort			lwidth(medthick) lcolor(gray) lpattern(dash) ) ///
				(connected y7 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(solid) mcolor(gray)) ///
				(rcap      yl7 yu7 years_rel_birth	if sib==0, sort			lwidth(medthick) lcolor(gray) lpattern(solid) ) ///
				(connected y24 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(dash_dot) mcolor(gray)) ///
				(rcap      y24 yu24 years_rel_birth	if sib==0, sort			lwidth(medthick) lcolor(gray) lpattern(dash_dot) ) ///
				,  ///
				xline(-1.5) legend(order( 1 "Siblings" 3 "First-observed match" 5 "Trajectory match")) ///
				ytitle(Change in percentile scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(B. Neighborhood requirement) name(req, replace)
	twoway 		(connected y6 years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(rcap      yl6 yu6 years_rel_birth	if sib==1, sort			lwidth(medthick) lcolor(black) lpattern(solid) ) ///
				(connected y3 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(dash) mcolor(gray)) ///
				(rcap      yl3 yu3 years_rel_birth	if sib==0, sort			lwidth(medthick) lcolor(gray) lpattern(dash) ) ///
				(connected y6 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(solid) mcolor(gray)) ///
				(rcap      yl6 yu6 years_rel_birth	if sib==0, sort			lwidth(medthick) lcolor(gray) lpattern(solid) ) ///
				(connected y23 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(dash_dot) mcolor(gray)) ///
				(rcap      y23 yu23 years_rel_birth	if sib==0, sort			lwidth(medthick) lcolor(gray) lpattern(dash_dot) ) ///
				,  ///
				xline(-1.5) legend(order( 1 "Siblings" 3 "First-observed match" 5 "Trajectory match" 7 "T=-2 match")) ///
				ytitle(Change in percentile scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(A. No neighborhood requirement) name(noreq, replace)
	grc1leg noreq req, graphregion(color(white)) ycommon
	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F3_posttrends.png, replace
	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F3_posttrends.emf, replace

*shading:
gen height1=.0
gen height2=-15
gen width=years_rel_birth-.5
	foreach i in 2 {
	twoway 		(area height2 width if years_rel_birth>0, fcolor(gs14) lcolor(gs14)) ///
				(connected y`i' years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y`i' years_rel_birth 	if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(longdash) mcolor(gray)) ///
				, xlabel(-4(1)1) /// 
				legend(col(4) order( 3 "Siblings" 4 "Matches" 1 "Match period" 2 "Year of birth")) ///
				ytitle(Change in Z-scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(ALL) name(y`i', replace)
				}
	forv i=3/4 {
	twoway 		(area height2 width if years_rel_birth<-3&years_rel_birth>-5, fcolor(gs14) lcolor(gs14)) ///
				(area height2 width if years_rel_birth>0, fcolor(gs12) lcolor(gs14)) ///
				(connected y`i' years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y`i' years_rel_birth 	if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(longdash) mcolor(gray)) ///
				, xlabel(-4(1)1) /// 
				legend(col(4) order( 3 "Siblings" 4 "Matches" 1 "Match period" 2 "Year of birth")) ///
				ytitle(Change in Z-scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(1ST OBS) name(y`i', replace)
				}
	forv i=19/20 {
	twoway 		(area height2 width if years_rel_birth<-1&years_rel_birth>-2, fcolor(gs14) lcolor(gs14)) ///
				(area height2 width if years_rel_birth>0, fcolor(gs12) lcolor(gs14)) ///
				(connected y`i' years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y`i' years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(longdash) mcolor(gray)) ///
				, xlabel(-4(1)1) /// 
				legend(col(4) order( 3 "Siblings" 4 "Matches" 1 "Match period" 2 "Year of birth")) ///
				ytitle(Change in Z-scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(T=-2) name(y`i', replace)
				}
	foreach i in 6 {
	twoway 		(area height2 width if years_rel_birth<-1, fcolor(gs14) lcolor(gs14)) ///
				(area height2 width if years_rel_birth>0, fcolor(gs12) lcolor(gs14)) ///
				(connected y`i' years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y`i' years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(longdash) mcolor(gray)) ///
				, xlabel(-4(1)1) /// 
				legend(col(4) order( 3 "Siblings" 4 "Matches" 1 "Match period" 2 "Year of birth")) ///
				ytitle(Change in Z-scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(IND) name(y`i', replace)
				}
	foreach i in 7 {
	twoway 		(area height2 width if years_rel_birth<-1, fcolor(gs14) lcolor(gs14)) ///
				(area height2 width if years_rel_birth>0, fcolor(gs12) lcolor(gs14)) ///
				(connected y`i' years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y`i' years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(longdash) mcolor(gray)) ///
				, xlabel(-4(1)1) /// 
				legend(col(4) order( 3 "Siblings" 4 "Matches" 1 "Match period" 2 "Year of birth")) ///
				ytitle(Change in Z-scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(IND+NBHD) name(y`i', replace)
				}
	foreach i in 23 {
	twoway 		(area height2 width if years_rel_birth<-1, fcolor(gs14) lcolor(gs14)) ///
				(area height2 width if years_rel_birth>0, fcolor(gs12) lcolor(gs14)) ///
				(connected y`i' years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y`i' years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(longdash) mcolor(gray)) ///
				, xlabel(-4(1)1) /// 
				legend(col(4) order( 3 "Siblings" 4 "Matches" 1 "Match period" 2 "Year of birth")) ///
				ytitle(Change in Z-scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(IND+FAM) name(y`i', replace)
				}
	foreach i in 24 {
	twoway 		(area height2 width if years_rel_birth<-1, fcolor(gs14) lcolor(gs14)) ///
				(area height2 width if years_rel_birth>0, fcolor(gs12) lcolor(gs14)) ///
				(connected y`i' years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y`i' years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(longdash) mcolor(gray)) ///
				, xlabel(-4(1)1) /// 
				legend(col(4) order( 3 "Siblings" 4 "Matches" 1 "Match period" 2 "Year of birth")) ///
				ytitle(Change in Z-scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(IND+FAM+NBHD) name(y`i', replace)
				}
**Alternative trajectories
	twoway 		(area height2 width if years_rel_birth<0&years_rel_birth>-4, fcolor(gs14) lcolor(gs14)) ///
				(area height2 width if years_rel_birth>0, fcolor(gs12) lcolor(gs14)) ///
				(connected y28 years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y28 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(longdash) mcolor(gray)) ///
				, xlabel(-4(1)1) ylabel(-.3(.1)0) /// 
				legend(col(4) order( 3 "Siblings" 4 "Matches" 1 "Match period" 2 "Year of birth")) ///
				ytitle(Change in Z-scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(A. Matched years -4 to -1) name(y28, replace)
	twoway 		(area height2 width if years_rel_birth<0&years_rel_birth>-3, fcolor(gs14) lcolor(gs14)) ///
				(area height2 width if years_rel_birth>0, fcolor(gs12) lcolor(gs14)) ///
				(connected y26 years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y26 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(longdash) mcolor(gray)) ///
				, xlabel(-4(1)1) ylabel(-.3(.1)0) /// 
				legend(col(4) order( 3 "Siblings" 4 "Matches" 1 "Match period" 2 "Year of birth")) ///
				ytitle(Change in Z-scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(B. Matched years =-3 to -1) name(y26, replace)
	twoway 		(area height2 width if years_rel_birth<-1, fcolor(gs14) lcolor(gs14)) ///
				(area height2 width if years_rel_birth>0, fcolor(gs12) lcolor(gs14)) ///
				(connected y27 years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y27 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(longdash) mcolor(gray)) ///
				, xlabel(-4(1)1) ylabel(-.3(.1)0) /// 
				legend(col(4) order( 3 "Siblings" 4 "Matches" 1 "Match period" 2 "Year of birth")) ///
				ytitle(Change in Z-scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(C. Matched years =-5 to -2) name(y27, replace)	
	twoway 		(area height2 width if years_rel_birth<-2&years_rel_birth>-4, fcolor(gs14) lcolor(gs14)) ///
				(area height2 width if years_rel_birth>0, fcolor(gs12) lcolor(gs14)) ///
				(connected y25 years_rel_birth		if sib==1, sort  		lwidth(medthick) lcolor(black) lpattern(solid) mcolor(black)) ///
				(connected y25 years_rel_birth 		if sib==0, sort	 		lwidth(medthick) lcolor(gray) lpattern(longdash) mcolor(gray)) ///
				, xlabel(-4(1)1) ylabel(-.3(.1)0) /// 
				legend(col(4) order( 3 "Siblings" 4 "Matches" 1 "Match period" 2 "Year of birth")) ///
				ytitle(Change in Z-scores) xtitle(Time until birth) graphregion(color(white)) ///
				title(D. Matched years =-4 to -3) name(y25, replace)
				
				
	grc1leg y2 y3 y19 y6 y23 y24, graphregion(color(white)) ycommon legendfrom(y23)

	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F3_posttrends_noSE.png, replace
	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F3_posttrends_noSE.emf, replace

	grc1leg y4 y20 y7 y24, graphregion(color(white)) ycommon

	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\FA1_posttrends_noSE_nbhd.png, replace
	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\FA1_posttrends_noSE_nbhd.emf, replace
	
	grc1leg y2 y3 y4 y19 y6 y7 y23 y24, graphregion(color(white)) ycommon col(4)

	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F6_all.png, replace
	graph export C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Figures\OlderSibReq\F6_all.emf, replace
	
	graph drop _all 
	
restore
/*
***FIGURE 7 - pre/post for moms
eststo clear
preserve
		gen grade8=0
		replace grade8=1 if grade==8
		gen grade10=0
		replace grade10=1 if grade==10
		gen mom_yrm5=mom*yrm5
		gen mom_yrm4=mom*yrm4
		gen mom_yrm3=mom*yrm3
		gen mom_yrm2=mom*yrm2
		gen mom_yrm1=mom*yrm1
		gen mom_yr0=mom*yr0
		gen mom_yr1=mom*yr1
			gen y102=0
			gen yl102=0
			gen yu102=0
			keep if years_rel_birth>=-5&years_rel_birth<=0
			egen temp =count(panel) if years_rel_birth==0, by(id2)
			tab temp, m
			replace temp=1 if temp>0&temp!=.
		egen include2=max(temp), by(id)
		gen include=1
				xi: eststo: xtreg pct yrm4 yrm3 yrm2 yrm1 yr0 i.age  if include2==1, i(panel) fe vce(cluster famid)  
				forv a = 1/4 {
					replace y102 =_b[yrm`a']					 	if years_rel_birth==-`a'&mom==1
					replace yl102=_b[yrm`a']-1.96*_se[yrm`a']   	if years_rel_birth==-`a'&mom==1
					replace yu102=_b[yrm`a']+1.96*_se[yrm`a']  		if years_rel_birth==-`a'&mom==1
						}
				foreach a in 0 {
					replace y102 =_b[yr`a']							if years_rel_birth==`a'&mom==1
					replace yl102=_b[yr`a']-1.96*_se[yr`a']    		if years_rel_birth==`a'&mom==1
					replace yu102=_b[yr`a']+1.96*_se[yr`a']    		if years_rel_birth==`a'&mom==1
						}
				collapse y102 yl102 yu102, by(years_rel_birth mom)
				tempfile tempfig102
				save `tempfig102', replace
restore

			
***Difference between groups
eststo clear
gen F1zscore=F.zscore
gen F2zscore=F2.zscore
gen F1pct=F.pct
gen F2pct=F2.pct
gen F1pcti=F.pcti
gen F2pcti=F2.pcti
gen Fdropout=F.dropout
gen Frepeat_later=F.repeat_later
gen Fjjc=F.jjc

foreach var of varlist female black frl {
	foreach outcome of varlist F1zscore F1pcti F1pct repeat_later dropout jjc col_ever col_ever_4yr col_degree col_degree_4yr  {
		forv i=1(-1)0 {
			eststo `var'`i': reg `outcome' sib female age1* famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i'  [aw=weight23]
			}
		suest `var'0 `var'1,  vce(cluster famid)
		test [`var'0_mean]sib=[`var'1_mean]sib
		gen test_sib_`var'_`outcome'=r(p)
		}
	}
eststo clear	
	sum test_*
	eststo: estpost sum test_*
	esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TAOther_group_comparisonINDFAM.rtf, ///
			main(mean) nonum nostar b(3) replace label onecell ///
			mtitle("P value of comparison") 
	drop test_*		
	
**IND_FAM_NBHD
foreach var of varlist female black frl {
	foreach outcome of varlist Fzscore F1pcti F1pct repeat_later dropout jjc col_ever col_ever_4yr col_degree col_degree_4yr  {
		forv i=1(-1)0 {
			eststo `var'`i': reg `outcome' sib female age1* famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i'  [aw=weight24]
			}
		suest `var'0 `var'1,  vce(cluster famid)
		test [`var'0_mean]sib=[`var'1_mean]sib
		gen test_sib_`var'_`outcome'=r(p)
		}
	}
eststo clear	
	sum test_*
	eststo: estpost sum test_*
	esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TAOther_group_comparison_INDFAMNBHD.rtf, ///
			main(mean) nonum nostar b(3) replace label onecell ///
			mtitle("P value of comparison") 
	drop test_*	
	
**IND
foreach var of varlist female black frl {
	foreach outcome of varlist Fzscore F1pcti F1pct repeat_later dropout jjc col_ever col_ever_4yr col_degree col_degree_4yr  {
		forv i=1(-1)0 {
			eststo `var'`i': reg `outcome' sib female age1* famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i'  [aw=weight6]
			}
		suest `var'0 `var'1,  vce(cluster famid)
		test [`var'0_mean]sib=[`var'1_mean]sib
		gen test_sib_`var'_`outcome'=r(p)
		}
	}
eststo clear	
	sum test_*
	eststo: estpost sum test_*
	esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TAOther_group_comparison_IND.rtf, ///
			main(mean) nonum nostar b(3) replace label onecell ///
			mtitle("P value of comparison") 
	drop test_*	

**IND_NBHD
foreach var of varlist female black frl {
	foreach outcome of varlist Fzscore F1pcti F1pct repeat_later dropout jjc col_ever col_ever_4yr col_degree col_degree_4yr  {
		forv i=1(-1)0 {
			eststo `var'`i': reg `outcome' sib female age1* famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first if `var'==`i'  [aw=weight7]
			}
		suest `var'0 `var'1,  vce(cluster famid)
		test [`var'0_mean]sib=[`var'1_mean]sib
		gen test_sib_`var'_`outcome'=r(p)
		}
	}
eststo clear	
	sum test_*
	eststo: estpost sum test_*
	esttab using C:\Users\jah970\Dropbox\Figlio_Heissel\Sibling_Spillover\Tables\OlderSibReq\TAOther_group_comparison_INDNBHD.rtf, ///
			main(mean) nonum nostar b(3) replace label onecell ///
			mtitle("P value of comparison") 
	drop test_*	
	
graph drop _all

***Calculating SD effects by race
tab race, nol
reg readnpi sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if race==5 [aw=weight23], vce(cluster famid)
reg mathnpi sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if race==5 [aw=weight23], vce(cluster famid)
reg mathnpi sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if race==2 [aw=weight23], vce(cluster famid)
reg readnpi sib female i.age famcount oldest frl black pctiL1 pctiL2 pctiL3 first_school_frl first_school_black first_school_pcti_first  if race==2 [aw=weight23], vce(cluster famid)
